@@ -60,9 +60,13 @@ class NameMixin:
         """Check if an object with given `name_or_slug` exists"""
         return self.get_id(name_or_slug) is not None
 
-    def get_by_name(self, name_or_slug: str) -> Dict:
+    def get_by_name(self, name_or_slug: str) -> Optional[Dict]:
         """Get by name or slug"""
-        return self.get(self.get_id(name_or_slug))
+        obj_id = self.get_id(name_or_slug)
+        if obj_id is None:
+            return None
+
+        return self.get(obj_id)
 
     def get_id(self, name_or_slug: str) -> Optional[int]:
         """Get the ID for an object by name or slug, returns None if not found"""
@@ -81,13 +85,12 @@ class NameMixin:
 class TagsMixin:
     """Mixin for taggable services"""
 
-    def get_by_tags(self, tags: List[str], without: bool = False) -> List[Dict]:
-        """Get all objects with `tags` or all objects without any of `tags`"""
+    def get_by_tags(
+        self, tags: List[str], without: bool = False, match_all: bool = True
+    ) -> List[Dict]:
+        """Get all objects with all or any of `tags` or all objects without any of `tags`"""
         all_objects = self.get_all()
 
-        if "results" in all_objects:
-            all_objects = all_objects["results"]
-
         if without:
             return [
                 obj
@@ -95,6 +98,13 @@ class TagsMixin:
                 if not any(tag in obj.get("tags", []) for tag in tags)
             ]
 
+        if match_all:
+            return [
+                obj
+                for obj in all_objects
+                if all(tag in obj.get("tags", []) for tag in tags)
+            ]
+
         return [
             obj
             for obj in all_objects
